@@ -20,10 +20,6 @@ use tokio::{
 };
 use tokio::{select, task};
 
-cfg_flatbuffers_helpers! {
-    use flatbuffers::FlatBufferBuilder;
-}
-
 #[derive(Debug)]
 pub(crate) struct WorldSocket<T, S, W>
 where
@@ -50,12 +46,11 @@ where
         game_time: &'static AtomicCell<GameTime>,
         timeout_read: u64,
         world_session: &'a Arc<T>,
-        world: &'static W,
     ) where
         S: AsyncWrite + AsyncRead,
     {
         select! {
-            _ = self.read(&mut reader, game_time, timeout_read, world_session, world) => {}
+            _ = self.read(&mut reader, game_time, timeout_read, world_session, self.world) => {}
             _ = Self::write(writer, rx) => {}
         }
     }
@@ -201,7 +196,6 @@ where
     async fn write(writer: WriteHalf<S>, mut rx: UnboundedReceiver<WriterMessage>) {
         let mut writer = BufWriter::new(writer);
         #[cfg(feature = "flatbuffers_helpers")]
-        let mut builder = flatbuffers::FlatBufferBuilder::new();
         while let Some(message) = rx.recv().await {
             match message {
                 WriterMessage::Close => break,
@@ -215,7 +209,7 @@ where
                         continue;
                     }
 
-                    if writer.write_all(&data.bytes()).await.is_err() {
+                    if writer.write_all(data.bytes()).await.is_err() {
                         break;
                     }
 
@@ -225,15 +219,6 @@ where
                         }
                     }
                 }
-                #[cfg(feature = "flatbuffers_helpers")]
-                WriterMessage::SendFlatbuffers(f) => {
-                    let bytes = f(&mut builder);
-                    if writer.write_all(&bytes).await.is_err() {
-                        break;
-                    }
-
-                    builder.reset();
-                }
                 WriterMessage::Flush => {
                     if let Err(error) = writer.flush().await {
                         log::error!("Error when flushing {:?}", error);
@@ -285,10 +270,6 @@ pub(crate) enum WriterMessage {
     Flush,
     CloseDelayed(Duration),
     Send(ContainerBytes, bool),
-    #[cfg(feature = "flatbuffers_helpers")]
-    SendFlatbuffers(
-        Box<dyn Fn(&mut FlatBufferBuilder<'static>) -> PoolObjectContainer<Vec<u8>> + Send + Sync>,
-    ),
 }
 
 #[cfg(test)]
